@@ -4,8 +4,8 @@
 	@date		11/2009
 */
 
-#ifndef __POINTER_MANAGER_H__
-#define __POINTER_MANAGER_H__
+#ifndef POINTER_MANAGER_H_
+#define POINTER_MANAGER_H_
 
 namespace input
 {
@@ -27,4 +27,4 @@ namespace input
 
 } // namespace input
 
-#endif // __POINTER_MANAGER_H__
+#endif // POINTER_MANAGER_H_
