@@ -3,8 +3,8 @@
 	@author		Albert Semenov
 	@date		08/2008
 */
-#ifndef __DEMO_KEEPER_H__
-#define __DEMO_KEEPER_H__
+#ifndef DEMO_KEEPER_H_
+#define DEMO_KEEPER_H_
 
 #include "Base/BaseDemoManager.h"
 
@@ -38,4 +38,4 @@ namespace demo
 
 } // namespace demo
 
-#endif // __DEMO_KEEPER_H__
+#endif // DEMO_KEEPER_H_
