@@ -3,8 +3,8 @@
 	@author		Albert Semenov
 	@date		09/2008
 */
-#ifndef __DEMO_KEEPER_H__
-#define __DEMO_KEEPER_H__
+#ifndef DEMO_KEEPER_H_
+#define DEMO_KEEPER_H_
 
 #include <MyGUI.h>
 #include "Base/BaseDemoManager.h"
@@ -54,4 +54,4 @@ namespace demo
 
 } // namespace demo
 
-#endif // __DEMO_KEEPER_H__
+#endif // DEMO_KEEPER_H_
