@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_BITWISE_H__
-#define __MYGUI_BITWISE_H__
+#ifndef MYGUI_BITWISE_H_
+#define MYGUI_BITWISE_H_
 
 #include "MyGUI_Prerequest.h"
 
@@ -58,4 +58,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_BITWISE_H__
+#endif // MYGUI_BITWISE_H_
