@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_CHILD_SKIN_INFO_H__
-#define __MYGUI_CHILD_SKIN_INFO_H__
+#ifndef MYGUI_CHILD_SKIN_INFO_H_
+#define MYGUI_CHILD_SKIN_INFO_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_WidgetStyle.h"
@@ -34,4 +34,4 @@ namespace MyGUI
 } // namespace MyGUI
 
 
-#endif // __MYGUI_CHILD_SKIN_INFO_H__
+#endif // MYGUI_CHILD_SKIN_INFO_H_
