@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_DATA_FILE_STREAM_H__
-#define __MYGUI_DATA_FILE_STREAM_H__
+#ifndef MYGUI_DATA_FILE_STREAM_H_
+#define MYGUI_DATA_FILE_STREAM_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_DataStream.h"
@@ -27,4 +27,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_DATA_STREAM_H__
+#endif // MYGUI_DATA_STREAM_H_
