@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_PLUGIN_H__
-#define __MYGUI_PLUGIN_H__
+#ifndef MYGUI_PLUGIN_H_
+#define MYGUI_PLUGIN_H_
 
 #include "MyGUI_Prerequest.h"
 #include <string>
@@ -47,4 +47,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_PLUGIN_H__
+#endif // MYGUI_PLUGIN_H_
