@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_TEXTURE_UTILITY_H__
-#define __MYGUI_TEXTURE_UTILITY_H__
+#ifndef MYGUI_TEXTURE_UTILITY_H_
+#define MYGUI_TEXTURE_UTILITY_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_Colour.h"
@@ -31,4 +31,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_TEXTURE_UTILITY_H__
+#endif // MYGUI_TEXTURE_UTILITY_H_
