@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_WIDGET_TRANSLATE_H__
-#define __MYGUI_WIDGET_TRANSLATE_H__
+#ifndef MYGUI_WIDGET_TRANSLATE_H_
+#define MYGUI_WIDGET_TRANSLATE_H_
 
 #include "MyGUI_Prerequest.h"
 
@@ -53,4 +53,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_WIDGET_TRANSLATE_H__
+#endif // MYGUI_WIDGET_TRANSLATE_H_
