@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_WINDOWS_CLIPBOARD_HANDLER_H__
-#define __MYGUI_WINDOWS_CLIPBOARD_HANDLER_H__
+#ifndef MYGUI_WINDOWS_CLIPBOARD_HANDLER_H_
+#define MYGUI_WINDOWS_CLIPBOARD_HANDLER_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_UString.h"
@@ -34,4 +34,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_WINDOWS_CLIPBOARD_HANDLER_H__
+#endif // MYGUI_WINDOWS_CLIPBOARD_HANDLER_H_
