@@ -3,8 +3,8 @@
 	@author     George Evmenov
 	@date       08/2009
 */
-#ifndef __DEMO_KEEPER_H__
-#define __DEMO_KEEPER_H__
+#ifndef DEMO_KEEPER_H_
+#define DEMO_KEEPER_H_
 
 #include "Base/BaseDemoManager.h"
 
@@ -33,4 +33,4 @@ namespace demo
 
 } // namespace demo
 
-#endif // __DEMO_KEEPER_H__
+#endif // DEMO_KEEPER_H_
